阅读文档 | Lires
Description: Lires documentations

Skip to content

# 阅读文档 ​

阅读文献并添加笔记

## 阅读器 ​

目前使用PDF.js Viewer作为阅读器，暂不支持文档编辑功能。 若想要编辑文档，请下载文档到本地，使用本地编辑器进行编辑后点击右上角`replace`按钮上传文档。

## 笔记 ​

本软件使用`markdown`格式来记录笔记，你可以在笔记中添加文本、图片、代码等内容。 在进行修改时，你可以使用`Ctrl+S`快捷键来保存笔记。

### 添加附件 ​

你可以通过点击`upload`按钮来 在笔记中添加图片、代码等附件，附件会被自动上传到服务器并在笔记中显示。

通过点击页面下方的`⬆️`上标按钮，可以打开附件管理窗口，你可以在这里查看和删除附件。

INFO

当笔记中的附件链接被删除时，附件仍然会保留在服务器上，但不会在笔记中显示，请在附件窗口中手动删除附件。

### Front Matter ​

笔记部分支持使用以下元数据来进行配置

yaml

    ---
    links:
        url_name1: url1
        url_name2: url2
        ...
    ---

目前仅支持`links`字段，用于添加链接（未来计划支持更多）。 在阅读文献时，你可以在文档的开头添加这个元数据， 此时，页面下端会显示一个链接列表，点击链接可以跳转到对应的网页。